@@ -11,6 +11,9 @@ class SqleeWarning(Warning):
         Sqlee Base Warning.
     """
 
+class VersionError(SqleeException):
+    pass
+
 class RepositoryNotFoundError(SqleeException):
     def __init__(self, repo_name=None, args="目标数据库 '{}' 不存在."):
         if repo_name:
