@@ -4,7 +4,7 @@
    版本: 1.0
 """
 from urllib.parse import urlencode
-from .exceptions import RepositoryNotFoundError
+
 import requests
 import json
 import base64
@@ -19,7 +19,7 @@ class GiteeRepo:
         self.repo = repo
         self.url = "https://gitee.com/" + user + "/" + repo + "/"
         if requests.get(url=self.url).status_code == 404:
-            raise RepositoryNotFoundError(repo)
+            raise NameError("仓库 %s 不存在." % (self.repo))
 
         self.types = {}
         self.types["int"] = int
@@ -59,7 +59,7 @@ class GiteeRepo:
                 else:
                     result.append(file["name"])
             else:
-                if file["name"] != ".keep":
+                if file["name"] != ".keep" and file["name"] != ".namespace":
                     if not dir:
                         if file["type"] != "dir":
                             try:
@@ -179,6 +179,8 @@ class GiteeRepo:
         return self.repo
 
 def make_repo(token=None, user=None, name=None, private=True, auto_init=True):
+    if not token or not user or not name:
+        raise ValueError("参数不全.")
     return requests.post(
         url = "https://gitee.com/api/v5/user/repos",
         data = {
